# Add generation of HMAC checksums of the final stripped binaries.
# %%define with lazy expansion is used here intentionally, because
# this needs to be expanded inside of a higher level macro that
# gets expanded itself.
%define __spec_install_post                  \
%{?__debug_package:%{__debug_install_post}}  \
%{__arch_install_post}                       \
%{__os_install_post}                         \
bindir="%{buildroot}%{_bindir}"              \
fipsdir="%{buildroot}%{_libdir}/fipscheck"   \
mkdir -p "$fipsdir"                          \
fipshmac -d "$fipsdir" "$bindir/%{name}"     \
%{nil}

# Always do out-of-source builds with CMake.
%{?__cmake_in_source_build:%undefine __cmake_in_source_build}

# Build and package Doxygen documentation?
%bcond_without    doxy

# Package summary.  Gets overwritten by subpackages otherwise.
%global pkg_sum   Online identification with German ID card (Personalausweis)


Name:             AusweisApp2
Version:          1.20.1
Release:          1%{?dist}
Summary:          %{pkg_sum}

# Init forge packaging helpers.
%global forgeurl  https://github.com/Governikus/%{name}
%global tag       %{version}
%forgemeta

License:          EUPL 1.2
URL:              https://www.ausweisapp.bund.de/en
Source0000:       %{forgesource}

# Upstreamed.
Patch00001:       %{forgeurl}/pull/27.patch#/%{name}-1.20.1-add_english_license_text.patch

BuildRequires:    cmake
BuildRequires:    desktop-file-utils
BuildRequires:    fipscheck
BuildRequires:    gcc-c++
BuildRequires:    help2man
BuildRequires:    http-parser-devel
BuildRequires:    java-openjdk-headless
BuildRequires:    libappstream-glib
BuildRequires:    libudev-devel
BuildRequires:    ninja-build
BuildRequires:    openssl-devel
BuildRequires:    pcsc-lite-devel
BuildRequires:    python3-devel
BuildRequires:    qt5-linguist
BuildRequires:    qt5-qtbase-devel
BuildRequires:    qt5-qtconnectivity-devel
BuildRequires:    qt5-qtdeclarative-devel
BuildRequires:    qt5-qtquickcontrols2-devel
BuildRequires:    qt5-qtsvg-devel
BuildRequires:    qt5-qtwebsockets-devel

# Lowercase package name.
%global lc_name   %{lua:print(string.lower(rpm.expand("%{name}")))}

# Make sure this package automatically replaces the security hazard
# built in some COPR.
Obsoletes:        %{name}                  < 1.20.1
Obsoletes:        %{lc_name}               < 1.20.1

# Provide the lowercase name for convenience as well.
Provides:         %{lc_name}               = %{version}-%{release}
Provides:         %{lc_name}%{?_isa}       = %{version}-%{release}

# Do not raise conflicts about shared license files.
Requires:         (%{name}-doc             = %{version}-%{release} if %{name}-doc)
Requires:         (%{name}-doc-api%{?_isa} = %{version}-%{release} if %{name}-doc-api)
Requires:         %{name}-data             = %{version}-%{release}

%description
The AusweisApp2 is a software to identify yourself online
with your ID card (Personalausweis) or your electronic
residence permit (Aufenthalts- / Niederlassungserlaubis).

The AusweisApp2 also offers you an integrated self-assessment
in which you are able to view your data that is stored on the
online ID.


%package data
Summary:          Architecture-independent files used by %{name}
BuildArch:        noarch

Requires:         %{name} = %{version}-%{release}
Requires:         hicolor-icon-theme

%description data
This package contains the architecture-independent files
used by %{name}.


%package doc
Summary:          User-documentation for %{name}
BuildArch:        noarch

BuildRequires:    hardlink
BuildRequires:    python3-sphinx
BuildRequires:    python3-sphinx_rtd_theme

# Do not raise conflicts about shared license files.
Requires:         (%{name}         = %{version}-%{release} if %{name})
%if %{with doxy}
Requires:         (%{name}-doc-api = %{version}-%{release} if %{name}-doc-api)
%else
Obsoletes:        %{name}-doc-api  < %{version}-%{release}
%endif

%description doc
This package contains the User-documentation for %{name}.


%if %{with doxy}
# This package must be arched, as the doxygen API documentation
# differs between architectures.
%package doc-api
Summary:          API-documentation for %{name}

BuildRequires:    doxygen
BuildRequires:    graphviz
BuildRequires:    hardlink

Requires:         (%{name}%{?_isa} = %{version}-%{release} if %{name})
Requires:         %{name}-doc      = %{version}-%{release}

%description doc-api
This package contains the API-documentation for %{name}.
%endif


%prep
%forgeautosetup -p 1


%build
%if !(0%{?fedora} || 0%{?rhel} > 8)
# Needed for EPEL-8.
mkdir -p %{_vpath_builddir}
pushd %{_vpath_builddir}
%endif

# The project does not ship any libraries that are meant to be
# consumed externally.  Thus we disable shared libs explicitly.
# See:  https://github.com/Governikus/AusweisApp2/pull/24
# and:  https://github.com/Governikus/AusweisApp2/pull/26
%cmake                                     \
  -DBUILD_SHARED_LIBS:BOOL=OFF             \
  -DBUILD_TESTING:BOOL=OFF                 \
  -DCMAKE_BUILD_TYPE:STRING=Release        \
  -DINTEGRATED_SDK:BOOL=OFF                \
  -DPYTHON_EXECUTABLE:STRING=%{__python3}  \
  -DSELFPACKER:BOOL=OFF                    \
  -G Ninja                                 \
%if !(0%{?fedora} || 0%{?rhel} > 8)
  ..
popd
%endif
%if (0%{?fedora} || 0%{?rhel} > 8)
%cmake_build

# Documentation.
%cmake_build --target inst inte notes sdk
%if %{with doxy}
%cmake_build --target doxy
%endif
%else
%ninja_build -C %{_vpath_builddir}

# Documentation.
%ninja_build -C %{_vpath_builddir} inst inte notes sdk
%if %{with doxy}
%ninja_build -C %{_vpath_builddir} doxy
%endif
%endif


%install
%if (0%{?fedora} || 0%{?rhel} > 8)
%cmake_install
%else
%ninja_install -C %{_vpath_builddir}
%endif
%find_lang %{lc_name} --with-qt

# Generate man-page.
mkdir -p %{buildroot}%{_mandir}/man1
help2man                                              \
  --no-discard-stderr --no-info                       \
  --manual="%{name}" --name="%{pkg_sum}" --section=1  \
  --help-option="--platform offscreen --help-all"     \
  --version-option="--platform offscreen --version"   \
  --output=%{buildroot}%{_mandir}/man1/%{name}.1      \
  %{buildroot}%{_bindir}/%{name}

# Excessive docs.
mkdir -p %{buildroot}%{_pkgdocdir}/{doxy,installation,integration,notes,sdk}
cp -p README.rst %{buildroot}%{_pkgdocdir}
%if %{with doxy}
cp -a %{_vpath_builddir}/doc/html/* %{buildroot}%{_pkgdocdir}/doxy
%else
rm -fr %{buildroot}%{_pkgdocdir}/doxy
%endif
cp -a %{_vpath_builddir}/docs/inst/html/* %{buildroot}%{_pkgdocdir}/installation
cp -a %{_vpath_builddir}/docs/inte/html/* %{buildroot}%{_pkgdocdir}/integration
cp -a %{_vpath_builddir}/docs/notes/html/* %{buildroot}%{_pkgdocdir}/notes
cp -a %{_vpath_builddir}/docs/sdk/html/* %{buildroot}%{_pkgdocdir}/sdk
find %{buildroot}%{_pkgdocdir} -type d -print0 | xargs -0 chmod -c 0755
find %{buildroot}%{_pkgdocdir} -type f -print0 | xargs -0 chmod -c 0644
find %{buildroot}%{_pkgdocdir} -type f -name '.*' -delete -print
hardlink -cfv %{buildroot}%{_pkgdocdir}


%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.metainfo.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop
%ctest


%files
%dir %{_libdir}/fipscheck
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/README.rst
%license AUTHORS
%license LICENSE.en.txt
%license LICENSE.txt
%{_bindir}/%{name}
%{_datadir}/applications/com.governikus.%{lc_name}.desktop
%{_libdir}/fipscheck/%{name}.hmac
%{_mandir}/man1/%{name}.1*
%{_metainfodir}/com.governikus.%{lc_name}.metainfo.xml


%files data -f %{lc_name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/%{name}.rcc
%{_datadir}/%{name}/config.json
%{_datadir}/icons/hicolor/96x96/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg


%files doc
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/README.rst
%doc %{_pkgdocdir}/installation
%doc %{_pkgdocdir}/integration
%doc %{_pkgdocdir}/notes
%doc %{_pkgdocdir}/sdk
%license %{_licensedir}/%{name}*


%if %{with doxy}
%files doc-api
%doc %{_pkgdocdir}/doxy
%endif


%changelog
* Wed Aug 19 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-1
- Initial import (#1851205)

* Fri Jul 17 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.11
- Use %%cmake_{build,install} macros on newer distributions

* Sat Jul 04 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.10
- Add license text in English language

* Fri Jun 26 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.9
- Also obsolete package with %%{name} previous to this package version

* Fri Jun 26 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.8
- Ensure archful packages always require equal architecture

* Fri Jun 26 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.7
- Make sure permissions of the documentation files are correct
- Remove hidden files in documentation
- Drop 'LICENSE.officially.txt', as it only applies to binary copies,
  which are distributed on behalf of the federal government of Germany

* Thu Jun 25 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.6
- Use '--help-all' option when generating man-page
- Split build of Doxygen API docs from building user docs

* Thu Jun 25 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.5
- Add generated man-page

* Thu Jun 25 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.4
- Use a macro for lowercase package name

* Thu Jun 25 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.3
- Use ninja-build instead of GNU Make to speed up the build a bit

* Thu Jun 25 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.2
- Adaptions for building on EPEL

* Wed Jun 24 2020 Björn Esser <besser82@fedoraproject.org> - 1.20.1-0.1
- Initial spec file for review
